@@ -11,14 +11,13 @@ class TestDOMCSSRule (TestCase):
         self.assertEqual(DOM_MEDIA_RULE, 4)
         self.assertEqual(DOM_FONT_FACE_RULE, 5)
         self.assertEqual(DOM_PAGE_RULE, 6)
-
-    @min_os_level('10.6')
-    def testConstants10_6(self):
-        self.assertEqual(DOM_VARIABLES_RULE, 7)
+        self.assertEqual(DOM_VARIABLES_RULE, 7) # Removed in 10.10(?)
+        self.assertEqual(DOM_KEYFRAMES_RULE, 7)
         self.assertEqual(DOM_WEBKIT_KEYFRAMES_RULE, 7)
         self.assertEqual(DOM_WEBKIT_KEYFRAME_RULE, 8)
-
-
+        self.assertEqual(DOM_KEYFRAME_RULE, 8)
+        self.assertEqual(DOM_SUPPORTS_RULE, 12)
+        self.assertEqual(DOM_WEBKIT_REGION_RULE, 16)
 
 if __name__ == "__main__":
     main()
